import { loadAllPresets } from '@storybook/core-common';
export { getPreviewBodyTemplate, getPreviewHeadTemplate } from '@storybook/core-common';
import { CLIOptions, LoadOptions, BuilderOptions, NormalizedStoriesSpecifier, Path, IndexEntry, DeprecatedIndexer, IndexerOptions, DocsIndexEntry, StoryIndex, StoryIndexer, Indexer, DocsOptions, StoryIndexEntry } from '@storybook/types';
import { EventType } from '@storybook/telemetry';

type BuildStaticStandaloneOptions = CLIOptions & LoadOptions & BuilderOptions & {
    outputDir: string;
};
declare function buildStaticStandalone(options: BuildStaticStandaloneOptions): Promise<void>;

declare function buildDevStandalone(options: CLIOptions & LoadOptions & BuilderOptions): Promise<{
    port: number;
    address: string;
    networkAddress: string;
}>;

type TelemetryOptions = {
    cliOptions: CLIOptions;
    presetOptions?: Parameters<typeof loadAllPresets>[0];
    printError?: (err: any) => void;
    skipPrompt?: boolean;
};
type ErrorLevel = 'none' | 'error' | 'full';
declare function getErrorLevel({ cliOptions, presetOptions, skipPrompt, }: TelemetryOptions): Promise<ErrorLevel>;
declare function sendTelemetryError(_error: unknown, eventType: EventType, options: TelemetryOptions): Promise<void>;
declare function withTelemetry<T>(eventType: EventType, options: TelemetryOptions, run: () => Promise<T>): Promise<T | undefined>;

declare function build(options?: any, frameworkOptions?: any): Promise<void | {
    port: number;
    address: string;
    networkAddress: string;
}>;

declare class IndexingError extends Error {
    importPaths: string[];
    constructor(message: string, importPaths: string[], stack?: string);
    pathsString(): string;
    toString(): string;
}

type StoryIndexEntryWithMetaId = StoryIndexEntry & {
    metaId?: string;
};
/** A .mdx file will produce a docs entry */
type DocsCacheEntry = DocsIndexEntry;
/** A *.stories.* file will produce a list of stories and possibly a docs entry */
type StoriesCacheEntry = {
    entries: (StoryIndexEntryWithMetaId | DocsIndexEntry)[];
    dependents: Path[];
    type: 'stories';
};
type ErrorEntry = {
    type: 'error';
    err: IndexingError;
};
type CacheEntry = false | StoriesCacheEntry | DocsCacheEntry | ErrorEntry;
type StoryIndexGeneratorOptions = {
    workingDir: Path;
    configDir: Path;
    storiesV2Compatibility: boolean;
    storyStoreV7: boolean;
    storyIndexers: StoryIndexer[];
    indexers: Indexer[];
    docs: DocsOptions;
};
/**
 * The StoryIndexGenerator extracts stories and docs entries for each file matching
 * (one or more) stories "specifiers", as defined in main.js.
 *
 * The output is a set of entries (see above for the types).
 *
 * Each file is treated as a stories or a (modern) docs file.
 *
 * A stories file is indexed by an indexer (passed in), which produces a list of stories.
 *   - If the stories have the `parameters.docsOnly` setting, they are disregarded.
 *   - If the stories have the 'stories-mdx' tag (i.e. were generated by a .stories.mdx file),
 *        OR autodocs is enabled, a docs entry is added pointing to the story file.
 *
 * A (modern) docs (.mdx) file is indexed, a docs entry is added.
 *
 * In the preview, a docs entry with either the `autodocs` or `stories-mdx` tags will be rendered
 * as a CSF file that exports an MDX template on the `docs.page` parameter, whereas
 * other docs entries are rendered as MDX files directly.
 *
 * The entries are "uniq"-ed and sorted. Stories entries are preferred to docs entries and
 * MDX docs entries are preferred to CSF templates (with warnings).
 */
declare class StoryIndexGenerator {
    readonly specifiers: NormalizedStoriesSpecifier[];
    readonly options: StoryIndexGeneratorOptions;
    private specifierToCache;
    private lastIndex?;
    private lastError?;
    constructor(specifiers: NormalizedStoriesSpecifier[], options: StoryIndexGeneratorOptions);
    initialize(): Promise<void>;
    /**
     * Run the updater function over all the empty cache entries
     */
    updateExtracted(updater: (specifier: NormalizedStoriesSpecifier, absolutePath: Path, existingEntry: CacheEntry) => Promise<CacheEntry>, overwrite?: boolean): Promise<void>;
    isDocsMdx(absolutePath: Path): boolean;
    ensureExtracted(): Promise<(IndexEntry | ErrorEntry)[]>;
    findDependencies(absoluteImports: Path[]): StoriesCacheEntry[];
    extractStories(specifier: NormalizedStoriesSpecifier, absolutePath: Path): Promise<StoriesCacheEntry | DocsCacheEntry>;
    extractStoriesFromDeprecatedIndexer({ indexer, indexerOptions, absolutePath, importPath, }: {
        indexer: DeprecatedIndexer['indexer'];
        indexerOptions: IndexerOptions;
        absolutePath: Path;
        importPath: Path;
    }): Promise<StoriesCacheEntry>;
    extractDocs(specifier: NormalizedStoriesSpecifier, absolutePath: Path): Promise<false | DocsIndexEntry>;
    chooseDuplicate(firstEntry: IndexEntry, secondEntry: IndexEntry): IndexEntry;
    sortStories(entries: StoryIndex['entries']): Promise<Record<string, IndexEntry>>;
    getIndex(): Promise<StoryIndex>;
    invalidate(specifier: NormalizedStoriesSpecifier, importPath: Path, removed: boolean): void;
    getStorySortParameter(): Promise<any>;
    storyFileNames(): string[];
}

export { BuildStaticStandaloneOptions, StoryIndexGenerator, build, buildDevStandalone, buildStaticStandalone, getErrorLevel, sendTelemetryError, withTelemetry };
